/**
 * EventConstraint.java
 * @author Matthew Farrellee
 *
 * Created 199909282027
 */

package org.datamanager.constraint;

import org.datamanager.event.DataManagerEvent;

import java.io.Serializable;

/**
 * Constraints define a set of events.  For any given event, a constraint's
 * accepts() method should return true if that event is a member of its set, and
 * false if it is not.
 */
public abstract interface EventConstraint extends Serializable
{
    /**
     * Matches all events.
     */
    public static final EventConstraint NONE = NoneConstraint.getInstance();

    /**
     * Reports whether a given entity fits the set of Entities defined by
     * this constraint.
     */
    public abstract boolean accepts(DataManagerEvent defendant);
}
