/**
 * OrConstraint.java
 * @author Benjamin Keil
 * @author Matthew Farrellee
 *
 * Created: 199910071543
 */

package org.datamanager.constraint;

import org.datamanager.kernel.Entity;
import org.datamanager.event.DataManagerEvent;

/**
 * OrConstraint takes two constraints in its constructor.  It matches all
 * entities that math one or both of those constraints.
 */

public class OrConstraint implements EntityConstraint, EventConstraint
	{
    
    private EntityConstraint pEntity, qEntity;
    private EventConstraint pEvent, qEvent;

    public OrConstraint(EntityConstraint p, EntityConstraint q) {
	this.pEntity = p; 
	this.qEntity = q;
    }

    public OrConstraint(EventConstraint p, EventConstraint q) {
	this.pEvent = p; 
	this.qEvent = q;
    }

    public boolean accepts(Entity defendant)
    {
	return (((pEntity != null) && (qEntity != null)) &&
			 (pEntity.accepts(defendant) || qEntity.accepts(defendant)));
    }

    public boolean accepts(DataManagerEvent defendant)
    {
	return (((pEvent != null) && (qEvent != null)) &&
			 (pEvent.accepts(defendant) || qEvent.accepts(defendant)));
    }
    
} // OrConstraint
