package org.datamanager.engine.cluster;

import org.datamanager.engine.tools.*;

/** 
 * This class calculates coordinates for documents 
 *
 * @author Aleksander Slominski
 */

public class Coordinates implements org.datamanager.kernel.EntityValue {

    /** @serial */
    private double[] _coord;

    public Coordinates(double[] coord) {
	_coord = coord;
    }


    /** 
     * Calculate cosinus between docs.
     * Identical is 1 (=cos(0)), completely dissimilar -1(=cos(180)).
     */
    public double getSimilarityTo(Coordinates c) {
	Assertion.check(c.size() == size());
	double sum = 0;
	for(int i = 0; i < _coord.length; ++i)
	    sum += _coord[i] * c._coord[i];
	double len = length() * c.length();
	//return (len != 0) ? (sum / len) : Double.POSITIVE_INFINITY;
	//Trace.println("dist","sum="+sum+" l="+length()+"c.l="+c.length());
	return sum / len;
    }

    public double length() {
	double sum = 0;
	for(int i = 0; i < _coord.length; ++i)
	    sum += _coord[i] * _coord[i];
	//Assertion.check(sum != 0); //???
	return Math.sqrt(sum);
    }


    public double getDistanceTo(Coordinates c) {
	Assertion.check(c.size() == size());
	double sum = 0;
	for(int i = 0; i < _coord.length; ++i)
	    sum += (_coord[i] - c._coord[i]) * (_coord[i] - c._coord[i]);
	return sum;
    }


    public int size() {
	return (_coord != null) ? _coord.length : 0;
    }

    public String toString() {
	StringBuffer buf = new StringBuffer("[");
	for(int i = 0;  i <  size(); ++i) {
	    buf.append(_coord[i]+",");
	}
	buf.append("]");
	return buf.toString();
    }
}
