package org.datamanager.engine.cluster;

import java.io.*;
import java.util.*;

import org.datamanager.kernel.*;
import org.datamanager.constraint.*;
import org.datamanager.exception.*;

import org.datamanager.engine.*;
import org.datamanager.engine.tools.*;

/**
 * This class adds EngineDocuments into a cluster.
 *
 * @author Aleksander Slominski
 * @author Chao
 */

public class EngineCluster implements Cluster {
    private static int counter = 0;
    /** @serial */
    private String name = "C" + ++counter;
    /** @serial */
    private Vector list = new Vector();
    /** @serial */
    private Entity clusterEntity;

    EngineCluster(){}

    public void setName(String name) {
	this.name = name;
    }

    public String getName() {
	return name;
    }


    public Entity[] getEntities() {
	synchronized(Engine.class) {
	    //Assertion.check(false);
	    Entity[] el = new Entity[list.size()];
	    for(int i = 0; i < list.size(); ++i) {
		EngineDocument ed = getDocument(i);
		Assertion.check(ed != null);
		el[i] = ed.getEntity();
	    }
	    return el;
	}
    }

    public void addEntities(Entity[] list) {
	synchronized(Engine.class) {
	    //Assertion.check(false);
	    for(int i = 0; list != null && i < list.length; ++i) {
		Entity e = list[i];
		if( e == null )
		    continue;
		 EngineDocument ed = EngineManager.getDefault().getDocumentFromEntity(e);
		 addDocument(ed);
	    }
	}
    }

    public void removeEntities(Entity[] list) {
	synchronized(Engine.class) {
	    //Assertion.check(false);
	    for(int i = 0; list != null && i < list.length; ++i) {
		Entity e = list[i];
		if( e == null )
		    continue;
		EngineDocument ed = EngineManager.getDefault().getDocumentFromEntity(e);
		removeDocument(ed);
	    }
	}
    }

    // more private operations
    public Entity getEntity() {
	return clusterEntity;
    }

    public void setEntity(Entity e) {
	clusterEntity = e;
    }


    public Iterator iterator() {
	return list.iterator();
    }




    /**
     * method adds an engine document
     */
    public void addDocument(EngineDocument ed) {
	if(!list.contains(ed))
	    list.add(ed);
    }

    public void addDocuments(EngineDocument[] docs) {
	for(int i = 0; i < docs.length; ++i) {
	    addDocument(docs[i]);
	}
    }

    public void removeDocument(EngineDocument ed) {
	list.remove(ed);
    }

    public boolean containsDocument(EngineDocument ed) {
	return list.contains(ed);
    }

    /**
     * method returns the engine document
     */
    public EngineDocument getDocument(int i) {
	return (EngineDocument) list.get(i);
    }


    public int size() {
	return list.size();
    }

    /**
     * convert to string
     */
    public String toString() {
	StringBuffer buf = new StringBuffer("Cluster:"+getName()+"=[");
	for(int i = 0; i < size(); ++i) {
	    EngineDocument ed = (EngineDocument)list.get(i);
	    buf.append(ed.getName()+",");
	}
	buf.append("]");
	return buf.toString();
    }

    private void trace(String s) {
	Trace.println(this.getClass(), s);
    }
}

