package org.datamanager.engine.filter;

/**
 * This class implements the Filter interface class.
 * It keeps track of the frequency of the words in a document 
 * when Filtering takes place. It's constructor does not take any arguments and
 * it's only method 'Process' is the one that actually keeps count of the words.
 * @author Chao
 * @author Aleksander Slominski
 */

import java.util.*;

public class FrequencyFilter implements Filter{

    /** @serial delimiters for separating the string into tokens*/
    private final static String delimiters= ".,\";:?!\n\t\r~!@%^&*()-+={}[]<> ,       ";
    
    public FrequencyFilter(){
    }

    /////////////////////////////////////////////////////////////////////////////////////////////

    /**
     * This is the method that actually does the counting of the words 
     */

    public Object process(Object content){
	//Debug.assert (content != null);
	if(content instanceof String == false)
	    throw new IllegalArgumentException("Expected string");
        StringTokenizer token = new  StringTokenizer((String)content, delimiters);  
	WeightedWordList wwl = new WeightedWordList();

        while(token.hasMoreElements()) {
	    String word = token.nextToken();
	    wwl.incrementCount(word);
	}
	wwl.doWeighting();
        return wwl;
    }
}




