package org.datamanager.engine.test;

import java.io.*;
import java.util.*;
import java.text.DecimalFormat;

import org.datamanager.engine.*;
import org.datamanager.engine.cluster.*;

/** This class tests the EngineManager. 
 * It shows how text documents can be searched, rank searched and clustered.
 *
 * @author Aleksander Slominski
 */

public class EngineManagerTester {
    
    /**
     * Simple demnstratin of current engine capapbilities :-)
     * It assumes that test docs are in org/datamanager/engine/test/text/*.txt
     *
     * @throws IOException
     */

    public static void main(String argv[]) throws IOException {

	EngineManager em = EngineManager.getDefault();

	//load test documents
	String dir = "org/datamanager/engine/test/text/";
	String ext = ".txt";
	EngineDocument[] docs = em.readDocuments(dir, ext);

	EngineCluster cluster = em.createEngineCluster();

	cluster.addDocuments(docs);

	em.addCluster(cluster);

	// upage semantic space
	em.updateSpace();

	//prepare keywords
	String[] keys = argv;
	if(argv.length == 0) {
	    keys = new String[] {"Engine"};
	    System.out.println("usage: specify keywords as arguments,");
	    System.out.println("No keywords to search specified, using default:'"+keys[0]+"'");
	}

	// prepare query
	StringBuffer buf = new StringBuffer();
	for(int i = 0; i < keys.length; ++i)
	    buf.append(keys[i]+" ");
	EngineDocument queryDoc = em.createEngineDocument("query pseudo document", "query", buf.toString());

	// do keyword search
	EngineCluster results = em.search(keys);
	for(int i =  0; i < results.size(); ++i) {
	    System.out.println(i+":"+results.getDocument(i));
	}
	if( results.size() == 0) {
	    System.out.println("Nothing can be found.");
	}

	// do query ranking search
	System.out.println("queryDoc = "+queryDoc);

	DecimalFormat fmt = new DecimalFormat(" 0.000;-#");
	Vector v = new Vector();
	for(Iterator i = em.getDocuments(); i.hasNext(); ) {
	    EngineDocument ed = (EngineDocument) i.next();
	    double dist = ed.getSimilarityTo(queryDoc);
	    //System.out.println(" -> "+ fmt.format(dist)+" dist to "+ed);
	    v.add(new RankedDoc(dist, ed));
	    	    
	}
	Collections.sort(v, new RankedDoc(0, null));
	for(Iterator i = v.iterator(); i.hasNext(); ) {
	    RankedDoc rd = (RankedDoc) i.next();
	    System.out.println(" -> "+ fmt.format(rd.rank) 
			       //+" "+fmt.format(rd.ed.getNorm(queryDoc)) 
			       + " "+ rd.ed);	    	    
	}

	System.out.println("Proximity matrix");
	for(int i = 0; i < docs.length; ++i) {
	    for(int j = 0; j < docs.length; ++j) {
		double dist = docs[i].getSimilarityTo(docs[j]); 
		System.out.print(fmt.format(dist) +" ");
		
	    }
	    System.out.println(" = "+i+"("+docs[i].getName()+")");
	}
	

    }

}

class RankedDoc implements Comparator {
    EngineDocument ed;
    double rank;

    public RankedDoc(double rank, EngineDocument ed) {
	this.rank = rank;
	this.ed = ed;
    }
	    

    public int compare(Object o1,
		       Object o2) {
	RankedDoc r1 = (RankedDoc) o1;
	RankedDoc r2 = (RankedDoc) o2;
	double d = -(r1.rank - r2.rank);
	return d < 0 ? -1 : d > 0 ? 1 : 0;
    }
    public boolean equals(Object obj) {
	RankedDoc rd = (RankedDoc) obj;
	return rd.rank == rank;
    }
}
