package org.datamanager.engine.test;

import java.io.*;
import test.framework.*;
import java.text.DecimalFormat;
import Jama.*;
import org.datamanager.engine.tools.*;

/**
 * Simple module tests with JUnit.
 *
 * @author Aleksander Slominski
 */

public class LSATest extends TestCase {
    private final static boolean PRINTING = false;
    //private static DecimalFormat fmt = new DecimalFormat("0.0");
    private static DecimalFormat fmt = new DecimalFormat("0.0000E00");

    public LSATest(String name) {
        super(name);
    }


    private static void print(String msg, Matrix m) {
	if(PRINTING) {
	    System.out.println("\n"+msg);
	    m.print(fmt,10);
	}
    }

   private static void check(Matrix X, Matrix Y) {
      double eps = Math.pow(2.0,-52.0);
      if (X.norm1() == 0. & Y.norm1() < 10*eps) return;
      if (Y.norm1() == 0. & X.norm1() < 10*eps) return;
      if (X.minus(Y).norm1() > 1000*eps*Math.max(X.norm1(),Y.norm1())) {
	  throw new RuntimeException("The norm of (X-Y) is too large: " +  Double.toString(X.minus(Y).norm1()));
      }
   }

    public void testSVD() {
	double[][] vals =  {{1.,2.,3.},{4.,5.,6.},{7.,8.,9.},{10.,11.,12.}};
	Matrix A = new Matrix(vals, 4, 3);
	SingularValueDecomposition svd = A.svd();
	Matrix B = svd.getU().times(svd.getS().times(svd.getV().transpose()));
	print("A=",A);
	print("U=",svd.getU());
	print("S=",svd.getS());
	print("V=",svd.getV());
	check(A, B);
    }

    public void testLSA() throws IOException {
	double[][] vals =  {{1.,2.,3.},{4.,5.,6.},{7.,8.,9.},{10.,11.,12.}};
	LSA lsa = new LSA();
	lsa.recomputeSVD(vals, 4, 3);
	double[] result;
	result = lsa.query(new double[]{1., 4., 7., 10.});
	Matrix m = Matrix.read(new BufferedReader(new StringReader("5.04533145931313800E-1 -7.60775681781422200E-1 1.25000000000000000E0")));
	check(new Matrix(result, 1), m);
	m = Matrix.read(new BufferedReader(new StringReader("2.14832754148908180E-1 2.15498214232478600E-1 -3.75000000000000000E-1")));
	lsa.query(new double[]{1., 2., 3., 4.});	
    }

    public static Test suite() {
        TestSuite suite = new TestSuite();

        suite.addTest(new LSATest("testSVD"));
        suite.addTest(new LSATest("testLSA"));
        return suite;
    }

    public static void main (String[] args) {
        test.textui.TestRunner.run (suite());
    }

}

