/**
 * AddEntityEvent.java
 */

package org.datamanager.event;

import org.datamanager.event.PoolEvent;
import org.datamanager.event.GenericEvent;
import org.datamanager.kernel.EventGenerator;
import org.datamanager.kernel.Entity;

/**
 * This event is fired when <code>Pool.add()</code>
 * is invoked.
 *
 * @author Matthew Farrellee
 */
public class AddEntityEvent
   extends GenericEvent
   implements PoolEvent
   {
   /**
    * The <code>Entity</code> that was added.
    */
   private Entity addedEntity;


   /**
    * The public constructor used to create an
    * <code>AddEntityEvent</code>.
    *
    * @param source The source of this event. Usually 'this.'
    * @param addedEntity The <code>Entity</code> that was added.
    */
   public AddEntityEvent(EventGenerator source, Entity addedEntity)
      {
      super(source);
      this.addedEntity = addedEntity;
      }


   /**
    * Report the new <code>Entity</code> that has been added to
    * the <code>Pool</code>.
    *
    * @return Entity The <code>Entity</code> that was added.
    */
   public Entity getAddedEntity()
      {
      return addedEntity;
      }

   
   /**
    * A toString() method to provide a meaningful <code>String</code>
    * representation of this event.
    *
    * @return String A meaningful <code>String</code> representation
    *                of this event.
    */
   public String toString()
      {
      return "AddEntityEvent[[source: " + source + "]" +
             "[addedEntity: " + addedEntity + "]" +
             "[time: " + time + "]]";
      }
   }