package org.datamanager.event;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EntityValue;
import org.datamanager.kernel.EventGenerator;

/**
 * This marker interface is the mother of all
 * events generated from within the kernel of
 * the <code>DataManager</code>.
 *
 * This is just a marker interface. It specifies
 * no unique methods of its own.
 * It does however extend <code>DataManagerEvent<code>
 * and therefore requires:
 * public EventGenerator getSource()
 * public long getTime()
 * public String toString()
 *
 * @author Matthew Farrellee
 */
public class EntityDetachedInterfaceEvent implements InterfaceEvent {
   
   private EventGenerator source;
   private long time;
   private Entity entity, detachedEntity;
   public EntityDetachedInterfaceEvent(EventGenerator source,
                      Entity entity,
                      Entity detachedEntity) {
      this.source = source;
      this.detachedEntity = detachedEntity;
      this.entity = entity;
      time = System.currentTimeMillis();
      }
   public EventGenerator getSource() {
      return source;
      }
   public long getTime() {
      return time;
      }
   public String toString() {
      return "BeginSessionInterfaceEvent[source,time]";
      }
   public Entity getEntity() {
      return entity;
      }
   public Entity getDetachedEntity() {
      return detachedEntity;
      }
   }