package org.datamanager.event;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EntityValue;
import org.datamanager.kernel.EventGenerator;

/**
 * This marker interface is the mother of all
 * events generated from within the kernel of
 * the <code>DataManager</code>.
 *
 * This is just a marker interface. It specifies
 * no unique methods of its own.
 * It does however extend <code>DataManagerEvent<code>
 * and therefore requires:
 * public EventGenerator getSource()
 * public long getTime()
 * public String toString()
 *
 * @author Matthew Farrellee
 */
public class EntityMovedInterfaceEvent implements InterfaceEvent {
   
   private EventGenerator source;
   private long time;
   private Entity entity;
   private double x,y,z;
   public EntityMovedInterfaceEvent(EventGenerator source, Entity entity, double x, double y, double z) {
      this.source = source;
      this.entity = entity;
      time = System.currentTimeMillis();
      this.x = x;
      this.y = y;
      this.z = z;
      }
   public EventGenerator getSource() {
      return source;
      }
   public long getTime() {
      return time;
      }
   public double getX() {
      return x;
      }
   public double getY() {
      return y;
      }
   public double getZ() {
      return z;
      }
   public String toString() {
      return "EntityMovedInterfaceEvent[source,time]";
      }
   public Entity getEntity() {
      return entity;
      }
   }