/**
 * NewsGroupDownloadEvent.java
 */
package org.datamanager.event;

import org.datamanager.kernel.EventGenerator;
import org.datamanager.event.GenericEvent;
import org.datamanager.event.CollectorEvent;

/**
 * This event is used to trigger the download of a newsgroup.
 *
 * @author Matthew Farrellee
 */
public class NewsGroupDownloadEvent
   extends GenericEvent
   implements CollectorEvent
   {
   private String group;
   private String server;

   /**
    * Create a new NewsGroupDownloadEvent.
    *
    * @param source The source of the event.
    * @param group The new group to downloaded.
    * @param server The server on which to find the group.
    */
   public NewsGroupDownloadEvent(EventGenerator source,
                                 String group,
                                 String server)
      {
      super(source);
      this.group = group;
      this.server = server;
      }


   /**
    * Get the name of the newsgroup.
    */
   public String getNewsGroup()
      {
      return group;
      }


   /**
    * Get the name of the news server.
    */
   public String getServer()
      {
      return server;
      }


   public String toString()
      {
      return "NewsGroupDownloadEvent[" +
         "[group: " + group + "]" +
         "[server: " + server + "]" +
         "[source: " + source + "]" +
         "[time: " + time + "]";
      }
   }