/**
 * RemoveEntityEvent.java
 */
package org.datamanager.event;

import org.datamanager.event.PoolEvent;
import org.datamanager.event.GenericEvent;
import org.datamanager.kernel.EventGenerator;
import org.datamanager.kernel.Entity;

/**
 * This event is fired when <code>Pool.remove()</code>
 * is invoked.
 *
 * @author Matthew Farrellee
 */
public class RemoveEntityEvent
   extends GenericEvent
   implements PoolEvent
    {
    /**
     * The <code>Entity</code> that was removed.
     */
    private Entity removedEntity;


    /**
     * The public constructor used to create a
     * <code>RemoveEntityEvent</code>.
     *
     * @param source The source of this event. Usually 'this.'
     * @param removedEntity The <code>Entity</code> that was removed.
     */
    public RemoveEntityEvent(EventGenerator source,
                              Entity removedEntity)
        {
        super(source);
        this.removedEntity = removedEntity;
        }

    /**
     * Remove the <code>Entity</code> that is being removed from the
     * <code>Pool></code>.
     *
     * @return Entity The <code>Entity</code> that was removed.
     */
    public Entity getRemovedEntity()
        {
        return removedEntity;
        }

    /**
      * A toString() method to provide a meaningful <code>String</code>
      * representation of this event.
      *
      * @return String A meaningful <code>String</code> representation
      *                of this event.
      */
    public String toString()
        {
        return "RemoveEntityEvent[" +
                 "[source: " + source + "]" +
               "[removedEntity: " + removedEntity + "]" +
               "[time: " + time + "]]";
        }
    }
