package org.datamanager.event;

import org.datamanager.event.KernelEvent;
import org.datamanager.event.GenericEvent;
import org.datamanager.kernel.EventGenerator;
import org.datamanager.kernel.EventHandler;
import org.datamanager.constraint.EventConstraint;

/**
 * This event is fired when
 * <code>EventGenerator.subscribe()</code> is invoked.
 *
 * @author Matthew Farrellee
 */
public class SubscribeEvent
   extends GenericEvent
   implements KernelEvent
   {
   /**
    * The <code>EventConstraint</code> that was subscribed.
    */
   private EventConstraint constraint;

   /**
    * The <code>EventHandler</code> that was subscribed.
    */
   private EventHandler handler;



   /**
    * The public constructor used to create a
    * <code>SubscribeEvent</code>.
    *
    * @param source The source of this event. Usually 'this.'
    * @param handler The <code>EventHandler</code> that was
    *         subscribed.
    * @param constraint The <code>EventConstraint</code> that was
    *            subscribed.
    */
   public SubscribeEvent(EventGenerator source,
                        EventHandler handler,
                        EventConstraint constraint)
      {
      super(source);
      this.handler = handler;
      this.constraint = constraint;
      }

   /**
    * Report the <code>EventHandler</code> that was subscribed.
    *
    * @return EventHandler The <code>EventHandler</code> that was
    *            subscribed.
    */
   public EventHandler getEventHandler()
      {
      return handler;
      }

   /**
    * Report the <code>EventConstraint</code> that was subscribed.
    *
    * @return EventConstraint The <code>EventConstraint</code> that was
    *            subscribed.
    */
   public EventConstraint getConstraint()
      {
      return constraint;
      }

   
   /**
    * A toString() method to provide a meaningful <code>String</code>
    * representation of this event.
    *
    * @return String A meaningful <code>String</code> representation
    *         of this event.
    */
   public String toString()
      {
      return "SubscribeEvent[[source: " + source + "]" +
         "[eventHandler: " + handler + "]" +
         "[eventconstraint: " + constraint + "]" +
         "[time: " + time + "]]";
      }
   }