/**
 * DataManager.java
 */

package org.datamanager.kernel;

import java.io.File;
import java.io.*;
import org.datamanager.kernel.Simpleton;
import org.datamanager.tools.Debug;

import org.datamanager.kernel.KernelWindow;



/**
 * This is the startup code for the datamanager. When invoked this
 * class will run all Simpletons and Interfaces that are located in
 * the startup directory.
 *
 * @author Matthew Farrellee
 */
public class DataManager
	{

	public static final String STARTUP = "startup";
	public static final String SIMPLETON = "simpletons";
	public static final String USER_INTERFACE = "userinterface";

	public static final File SIMPLETON_DIRECTORY =
		new File(STARTUP + File.separator + SIMPLETON);

	public static final File USER_INTERFACE_DIRECTORY =
		new File(STARTUP + File.separator + USER_INTERFACE);

	public static final String DEFAULT_POOL = "DefaultPool";
	public static final String OBJECT_STORE = "ObjectStore";

	public DataManager()
		{
		}

	public static void main(String[] input)
		throws Throwable
		{
		System.runFinalizersOnExit(true);
		
		Debug.setDebugger(true);
		//Debug.setMessenger(true);
		//Debug.setIgnorer(true);
		//Debug.addIgnore("org.datamanager.kernel.");

		KernelWindow control = new KernelWindow();
		control.pack();
		control.setVisible(true);

		//File output = new File("output");
		//PrintStream fOut = new PrintStream(new FileOutputStream(output));
		//System.setErr(fOut);
		//System.setOut(fOut);

		/** Start Kernel Processes **/
		
		// This process loads all Simpletons.
		ThreadManager.getInstance().register(
			new SimpletonLoaderProcess(control, SIMPLETON_DIRECTORY),
			(Thread.MIN_PRIORITY + 1));

		// This process loads all UserInterfaces.
		ThreadManager.getInstance().register(
			new UserInterfaceLoaderProcess(control, USER_INTERFACE_DIRECTORY),
			(Thread.MIN_PRIORITY + 1));
		}
	}