/**
 * IdentifierManager.java
 *
 * Created: 199911191644
 */

package org.datamanager.kernel;

import java.io.*;

/**
 * The IdentifierManager class is a source of unique Identifiers.
 *
 * @author Benjamin Keil
 * @author Matthew Farrellee
 */
class IdentifierManager implements Serializable
   {
   private static IdentifierManager instance = new IdentifierManager();
   private int nextIdentifier;

   private IdentifierManager()
      {
      }

   /**
    * Returns the Singleton instance of the IdentifierManager.
    */
   public static IdentifierManager getInstance()
      {
      return instance;
      }

   /**
    * Returns the next available unique identifier.
    */
   public Identifier getNextIdentifier()
      {
      return new SimpleIdentifier(nextIdentifier++);
      }

   /**
    * The SimpleIdentifier is only an int.  As Hashtable uses ints for
    * hash codes, and we use Hashtables to map identifiers to Entities,
    * there is no sense in using any larger datatype.
    */
   class SimpleIdentifier implements Identifier, Serializable
      {
      private final int identifier;

      public SimpleIdentifier(int identifier)
         {
         this.identifier = identifier;
         }

      public int hashCode()
         {
         return identifier;
         }

      public boolean equals(Object object)
         {
			try
				{
				return ((SimpleIdentifier) object).identifier == this.identifier;
				}
			catch (ClassCastException exception)
				{
            return false;
				}
			}
		}
	}






