package org.datamanager.tools;
/**
 * A class to make compiling KnownSpace easier.  It first deletes all class files in every
 * subfolder.  Then it compiles four different directories.
 */
import java.io.File;
import java.io.FileFilter;
import java.io.IOException;
public class MakeKnownspace {
	public static final String CLASSPATH = ".;./startup/simpletons;./startup/userinterface";
	public static void main(String[] parameters) throws IOException {
		if (parameters.length > 0) {
			if (parameters[0].equals("-remove")) {
				removeDirectories();
				}
			else if (parameters[0].equals("-compile")) {
				compileKnownspace();
				}
			}
		else {
			removeDirectories();
			compileKnownspace();
			}
		}
	public static void removeDirectories() throws IOException {
		File orgRoot = new File("org");
		if (orgRoot.exists()) {
			removeAllClassFiles(orgRoot);
			}
		File startupRoot = new File("startup");
		if (startupRoot.exists()) {
			removeAllClassFiles(startupRoot);
			}
		}
	public static void compileKnownspace() throws IOException {
		System.out.println("Compiling");
		File startupRoot = new File("startup");
		if (startupRoot.exists()) {
			System.out.println("Compiling startup");		
			exec("javac startup/userinterface/*.java");
			exec("javac startup/simpletons/*.java");
			}
		File orgRoot = new File("org");
		if (orgRoot.exists()) {
			System.out.println("compiling datamanager/*");
			exec("javac " + 
					"org/datamanager/userinterface/cerulean/Cerulean.java");
			exec("javac " +
					"org/datamanager/kernel/DataManager.java");
			}
		}
	public static void removeAllClassFiles(File directory) {
		System.out.println("opening: " + directory.getName());
		File[] subFiles = directory.listFiles();
		for (int i = 0; i < subFiles.length; i++) {
			if (subFiles[i].isDirectory()) {
				removeAllClassFiles(subFiles[i]);
				}
			}
		File[] classFiles = directory.listFiles(new ClassFileFilter());
		for (int i = 0; i < classFiles.length; i++) {
			classFiles[i].delete();
			System.out.println("deleting: "+classFiles[i].getName());
			}
		}


    private static void exec(String command) throws IOException {
		Runtime runtime = Runtime.getRuntime();
		Process p = runtime.exec(command);
		System.err.println("Executing: "+command);
		try {
		    int exitCode = p.waitFor();
		    if(exitCode != 0) {
			System.err.println("Command "+command+" exited with code "+exitCode);
		    }
		} catch(InterruptedException ex) {
		    System.err.println("Command "+command+" was interrupted : "+ex);
		}

	}
}

/**
 * ClassFileFilter filters out all files except for those ending in .class
 */
class ClassFileFilter implements FileFilter {
	public boolean accept(File file) {
		boolean isClassFile = false;
		boolean isAccepted = false;
		String fileName = file.getName();
		if (fileName.lastIndexOf(".class") != -1) {
			isClassFile = true;
			}
		if (file.isFile() && isClassFile) {
			isAccepted = true;
			}
		if ((fileName.indexOf("MakeKnownspace") >=0) ||
			 (fileName.indexOf("ClassFileFilter") >= 0)) {
			isAccepted = false;
			}
		return isAccepted;
		}
	}
