package org.datamanager.userinterface.cerulean;

import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.Toolkit;
import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.JPanel;
import org.datamanager.constraint.EntityConstraint;
import org.datamanager.tools.Debug;
import org.datamanager.userinterface.cerulean.model.InterfaceCluster;
import org.datamanager.userinterface.cerulean.model.InterfaceClusterManager;
import org.datamanager.userinterface.cerulean.model.InterfaceEntityManager;
import org.datamanager.userinterface.cerulean.model.data.storage.InterfaceEntityList;
import org.datamanager.userinterface.cerulean.model.data.storage.ClusterList;
import org.datamanager.userinterface.cerulean.model.kernel.KernelProxy;
import org.datamanager.userinterface.cerulean.sounds.AutomaticSoundPlayer;
import org.datamanager.userinterface.cerulean.sounds.SoundRequestHandler;
import org.datamanager.userinterface.cerulean.view.component.LayeredClusterPanel;
import org.datamanager.userinterface.cerulean.view.component.StageComponent;
import org.datamanager.userinterface.cerulean.view.search.SearchPane;
import org.datamanager.userinterface.cerulean.view.sidepanel.SidePanel;
import org.datamanager.constraint.*;
import java.io.File;

/**
 *This class throws everthing together to show Cerulean.
 *
 *@author Gordon Murphy (gpmurphy@indiana.edu)
 *@author Bryan Dawson (bdawson@indiana.edu)
 *
 */

public class CeruleanFrame extends JFrame
   {
       /**
	*This is a reference to the SoundRequestHandler, so that a reference 
	*always a live thread.  See the SoundRequestHandler for why this
	*is necessary
	*/
       private SoundRequestHandler sounds;
       
       /**
	*This cluster diplays all of the entities in the pool on startup
	*/
       private InterfaceCluster allCluster; 
       ///////////////////////////////////////////////////////////////
       /**
	* The only constructor... throws everything together
	*/
       public CeruleanFrame()
          {
	      super("KnownSpace -- Cerulean");
	      
	      //start the sounds going.
	      sounds = SoundRequestHandler.getInstance();
	      
	      //Add the AutomaticSoundPlayer to listen for Cerulean events.
	      AutomaticSoundPlayer player = new AutomaticSoundPlayer();
	      InterfaceClusterManager.getInstance().addClusterListener(player);
	      InterfaceEntityManager.getInstance().addEntityListener(player);
	      
	      LayeredClusterPanel c = new LayeredClusterPanel();
	      Container contents = getContentPane();
	      contents.setLayout(new BorderLayout());
	      
	      //This is the panel that will hold the search, balcony, and 
	      JPanel side = new JPanel(new BorderLayout());
	      SidePanel sidePanel = new SidePanel();
	      SearchPane search = new SearchPane();
	      
	      //setup the icon for the frame 
	      String separator = System.getProperty("file.separator");
	      this.setIconImage( Toolkit.getDefaultToolkit().getImage(
		   "org"+separator+"datamanager"+separator+"userinterface"
		   +separator+"cerulean"+separator+"images"+separator+
		   "icon.gif") );
	      
	      //add the 3 parts of cerulean
	      contents.add(c, BorderLayout.CENTER);
	      side.add(search, BorderLayout.NORTH);
	      side.add(sidePanel, BorderLayout.CENTER);
	      contents.add(side, BorderLayout.EAST);

	      //add th clusters 
	      allCluster  = new InterfaceCluster("Contains all Entities");
	      c.getTabPane().addCluster(allCluster);
	      c.getTabPane().addRecommendedCluster();
	      c.getTabPane().addSearchCluster();
	      c.getTabPane().addNewEntitiesCluster();
/*		ClusterList clusterList = findClustersInPool();
		for (int i = 0; i < clusterList.size(); i++) {
			c.getTabPane().addCluster(clusterList.elementAt(i));
			}
*/

	      JComponent l = (JComponent)c.getGlassPane();
	      StageComponent c1 = c.getStagePane().getStage();
	      
	      //set the size 
	      this.setSize(640, 480);
	      //this.show();
	      //this.invalidate();
	  }
       //////////////////////////////////////////////////////////////
       /**
        *Fills the "All" cluster with the current entities in the pool
	  */
       public void fillAllCluster()
          {
	      InterfaceEntityList list = KernelProxy.getInstance().search(EntityConstraint.NONE);
	      allCluster.addEntities(list);
	  }
/*
	 public ClusterList findClustersInPool() {
	      InterfaceEntityList list = KernelProxy.getInstance().search(
							new AttributeExistsConstraint(
								new NameEqualsConstraint("InterfaceCluster")
								)
							);
	      ClusterList clusterList = new ClusterList();
		for (int i = 0; i < list.size(); i++) {
			System.out.println(i);
			clusterList.addCluster(new InterfaceCluster( list.elementAt(i) ) );
			}
		return clusterList;
		}
*/
}  
