package org.datamanager.userinterface.cerulean.controller.sidepanel;

import org.datamanager.userinterface.cerulean.view.sidepanel.SidePanel;
import org.datamanager.userinterface.cerulean.view.undo.HistoryPane;
import java.awt.event.ComponentAdapter;
import java.awt.event.ComponentEvent;
/**
 *This class repositions the divider of the SidePanel so that the History 
 *section is the correct size of the SidePanel
 *
 *@author Bryan Dawson (bdawson@indiana.edu)
 *@author Gordon Murphy (gpmurphy@indiana.edu)
 *
 *@see org.datamanager.userinterface.cerulean.view.sidepanel.SidePanel
 *@see org.datamanager.userinterface.cerulean.view.undo.HistoryPane
 */
//  Methods:
//  ~~~~~~~
//  public SidePanelResizer(HistoryPane, SidePanel)
//       The two objects are the SidePanel and HistoryPane to watch
//  public void componentResized(ComponentEvent)
//  public void componentShown(ComponentEvent)
//      Both of these methods reposition the divider of the sidePanel, based 
//      on the PERCENTAGE_OF_SPLITPANE from HistoryPane
///////////////////////////////////////////////////////////////////

public class SidePanelResizer extends ComponentAdapter
   {
   /**
    *The HistoryPane which is queried to resized the SidePanel correctly
    */
   private HistoryPane history;
   
   /**
    *The SidePanel object in which the divider location is set.
    */
    private SidePanel sidePanel;

   /////////////////////////////////////////////////////////////////
   /**The only constructor.
    *@param history The HistoryPane base the size on.
    *@param sidePanel This is the SidePanel Object that this is a listener for
    */ 
   public SidePanelResizer(HistoryPane history, SidePanel sidePanel)
      {
      this.history = history;
      this.sidePanel = sidePanel;
      }
   ///////////////////////////////////////////////////////////////////
   /**
    *This is called when the SidePanel object is resized.  It sets the divider
    *location based on the HistoryPane.
    *@param event Fired when the SidePanel is resized.
    */
   public void componentResized(ComponentEvent event)
      {
      if(history.isUp())
         sidePanel.setDividerLocation(HistoryPane.PERCENTAGE_OF_SPLITPANE);
      else
	 sidePanel.setDividerLocation(sidePanel.getMaximumDividerLocation()); 
      }
    
   ////////////////////////////////////////////////////////////////////  
   /**
    *This is called when the SidePanel is first shown in its container.It 
    *sets the divider location based on the HistoryPane.
    *@param event Fired when the SidePanel is shown.
    */
   public void componentShown(ComponentEvent event)
      {
      if(history.isUp())
         sidePanel.setDividerLocation(HistoryPane.PERCENTAGE_OF_SPLITPANE);
      else
	 sidePanel.setDividerLocation(sidePanel.getMaximumDividerLocation()); 
      }      
      
   }      
