package org.datamanager.userinterface.cerulean.controller.undo;

import org.datamanager.userinterface.cerulean.view.undo.HistoryList;
import org.datamanager.userinterface.cerulean.model.undo.InterfaceUndoManager;
import org.datamanager.userinterface.cerulean.model.undo.InterfaceUndoEdit;
import org.datamanager.userinterface.cerulean.model.undo.HistoryListModel;
import java.awt.event.MouseAdapter;
//import java.awt.event.MouseMotionListener;
import java.awt.event.MouseEvent;
import java.awt.Point;
import javax.swing.undo.UndoableEdit;
/**
 *This class listens for user selection in the HistoryList.  When the user 
 *clicks (single-clicks) on an InterfaceUndoEdit then this class determines
 * if it is an undo or a redo, and calls either undoTo or redoTo respectively
 * in the InterfaceUndoManager with that InterfaceUndoEdit.
 *
 *@author Bryan Dawson (bdawson@indiana.edu)
 *@author Gordon Murphy (gpmurphy@indiana.edu)
 *
 *@see org.datamanager.userinterface.cerulean.model.undo.InterfaceUndoManager
 *@see org.datamanager.userinterface.cerulean.model.undo.InterfaceUndoEdit
 */

public class ListClickHandler extends MouseAdapter 
   {
   private HistoryList list;
     
   public ListClickHandler(HistoryList list)
      {
      this.list = list;
      }
   ////////////////////////////////////////////////////////////////   
   /**
    *This method gets called when the user clicks on one of the 
    *InterfaceUndoEdits in the list.
    *@param event Fired when the user makes a selection in the list.
    */
   public void mouseClicked(MouseEvent event)
      {
      if(event.getClickCount() == 1)
      	 {
      	 int index = list.locationToIndex(new Point(event.getX(), event.getY()));
         if(index != -1)
            {
            HistoryListModel model = (HistoryListModel)list.getModel();
            InterfaceUndoEdit edit = (InterfaceUndoEdit)model.elementAt(index);
            if(edit.canUndo())
            	{
            	InterfaceUndoManager.getInstance().undoTo(edit);
		list.repaint();
		}
	    else
	    	{
	    	InterfaceUndoManager.getInstance().redoTo(edit);
	   	list.repaint();
	      	}
	     
	     }          	     
          }
      } 
  //   //////////////////////////////////////////////////////////////
//     /** Tracks if the user is dragging the mouse.  It only undoes/redoes
//      *  an edit if the user moves to a different edit than the previous one.
//     */   
//     public void mouseDragged(MouseEvent event)
//        {
//        int index = list.locationToIndex(new Point(event.getX(), event.getY()));
//        if(index != -1)
//           {
//           HistoryListModel model = (HistoryListModel)list.getModel();
//           InterfaceUndoEdit currentEdit = (InterfaceUndoEdit)model.elementAt(index);
//           //if(!previousEdit.equals(currentEdit))
//           //   {
//              if(currentEdit.canUndo())
//                 {
//                 InterfaceUndoManager.getInstance().undoTo(currentEdit);
//  	       list.repaint();
//  	       }
//  	    else
//  	       {
//  	       InterfaceUndoManager.getInstance().redoTo(currentEdit);
//  	       list.repaint();
//  	       }
//  	    previousEdit = currentEdit;   
//             // }              
//           }
//        }                         	     		
//     ////////////////////////////////////////////////////////////////
//     /* Needs to be implemented from MouseMotionListener inteface
//     */
//     public void mouseMoved(MouseEvent event) {}
         
           
}
