/*
class org.datamanager.userinterface.cerulean.model.InterfaceEntity
KnownSpace: Cerulean

Authors:
~~~~~~~~
Gordon Murphy, gpmurphy@indiana.edu
Bryan Dawson, bdawson@indiana.edu
*/

package org.datamanager.userinterface.cerulean.model;

import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.tools.*;
import org.datamanager.userinterface.cerulean.model.kernel.*;
import org.datamanager.userinterface.cerulean.model.event.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;
import org.datamanager.userinterface.cerulean.model.data.storage.*;
import org.datamanager.kernel.Entity;
import org.datamanager.kernel.*;
import org.datamanager.constraint.*;
import org.datamanager.passiveentityvalue.*;
import org.datamanager.exception.DataManagerException;
import java.io.Serializable;
/**
 * This class wraps
 */
public class InterfaceAttribute extends InterfaceEntity implements Serializable {
	private String entityName;
/**
 * Create a new InterfaceEntity from the given Entity
 * @param entity an entity the InterfaceEntity will represent
 */
	public InterfaceAttribute(Entity entity) {
		super(entity);		
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Create a null instance of a InterfaceEntity
 */
	public InterfaceAttribute() {
		this("");
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Create a null instance of a InterfaceEntity
 */
	public InterfaceAttribute(String name) {
		this(KernelProxy.getInstance().createAttribute(name));
		}

	protected void createName() {
		KernelProxy kernel = KernelProxy.getInstance();
		String name = kernel.getEntityName(getEntity());
		setEntityName(name);
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Sets the entity's name.
 * @param entityName the new name of the entity
 */
	public void setEntityName(String entityName) {
		this.entityName = entityName;
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Gets the entity's name.
 * @param entityName the new name of the entity
 * @return the entity's name
 */
	public String getEntityName() {
		return entityName;
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Get the name of the Entity
 * @return the entity's name
 */
	public String getName() {
		return getEntityName();
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Overriden so as not to fire any EntityEvents
 */
	public void setCreated(Object source) {
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Overriden so as not to fire any EntityEvents
 */
	public void setSelected(Object source) {
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Overriden so as not to fire any EntityEvents
 */
	public void setUnselected(Object source) {
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Overriden so as not to fire any EntityEvents
 */
	public void setOpened(Object source) {
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Overriden so as not to fire any EntityEvents
 */
	public void setAttached(Object source, InterfaceEntity attachedEntity) {
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Overriden so as not to fire any EntityEvents
 */
	public void setDetached(Object source, InterfaceEntity detachedEntity) {
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Overriden so as not to fire any EntityEvents
 */
	public void setMoved(Object source, int x, int y, int z) {}

////////////////////////////////////////////////////////////////////////////////
/**
 * Overriden to not fire an event.
 * @param source the source of the selection
 */
	public void setModified(Object source) {}	
	public String toString() {
		return "InterfaceAttribute: "+ getEntityName() + " [value: " + getValue() + "]";
		}
	}