/*
class org.datamanager.userinterface.cerulean.model.Personalizeable
KnownSpace: Cerulean

Authors:
~~~~~~~~
Gordon Murphy, gpmurphy@indiana.edu
Bryan Dawson, bdawson@indiana.edu
*/
////////////////////////////////////////////////////////////////////////////////

package org.datamanager.userinterface.cerulean.model;

import java.awt.Paint;
import java.awt.Shape;
import java.lang.String;
import org.datamanager.userinterface.cerulean.view.icon.CIcon;

////////////////////////////////////////////////////////////////////////////////

/**
 * An interface that all objects that wish to be personalized
 * using the Personalizer dialog box must implement.
 */

public interface Personalizable {
////////////////////////////////////////////////////////////////////////////////
/**
 * Change the displayed paint of the object.
 * @param paint the new paint type the object will display.
 */
	public void setPaint(Paint paint);

////////////////////////////////////////////////////////////////////////////////
/**
 * Change the displayed name of the object.
 * @param name the new name.
 */
	public void setName(String name);

////////////////////////////////////////////////////////////////////////////////
/**
 * Change the shape of the object.
 * @param shape the new shape of the object.
 */
	public void setShape(Shape shape);

////////////////////////////////////////////////////////////////////////////////
/**
 * Change the icon of the object.
 * @param icon the new icon used to display the object.
 */
	public void setIcon(CIcon icon);

////////////////////////////////////////////////////////////////////////////////
/**
 * Get the current paint of the object.
 * @return the current paint
 */
	public Paint getPaint();

////////////////////////////////////////////////////////////////////////////////
/**
 * Get the current name of the object.
 * @return the current name
 */
	public String getName();

////////////////////////////////////////////////////////////////////////////////
/**
 * Get the current shape of the object.
 * @return the current shape
 */
	public Shape getShape();

////////////////////////////////////////////////////////////////////////////////
/**
 * Get the current icon of the object.
 * @return the current icon
 */
	public CIcon getIcon();
////////////////////////////////////////////////////////////////////////////////
	}