/*
class org.datamanager.userinterface.cerulean.model.InterfaceEntityManager
KnownSpace: Cerulean

Authors:
~~~~~~~~
Gordon Murphy, gpmurphy@indiana.edu
Bryan Dawson, bdawson@indiana.edu
*/

////////////////////////////////////////////////////////////////////////////////

package org.datamanager.userinterface.cerulean.model;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Container;
import java.awt.Dialog;
import java.awt.Frame;
import java.awt.Window;
import java.awt.event.ActionEvent;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JDialog;
import javax.swing.JTabbedPane;
import javax.swing.SwingUtilities;
import org.datamanager.userinterface.cerulean.model.personalize.NameChooserPanel;
import org.datamanager.userinterface.cerulean.model.personalize.PaintChooserPanel;
import org.datamanager.userinterface.cerulean.model.personalize.ShapeChooserPanel;

////////////////////////////////////////////////////////////////////////////////
/**
 * Creates a new Personalizer window with tabs for choosing a name,
 * a paint type, i.e. a color, a texture, a gradient, and for choosing shape
 * and size.
 */

public class Personalizer extends JDialog {
	private Personalizable entity;
	private JTabbedPane tabbedPane;

////////////////////////////////////////////////////////////////////////////////
/**
 * Defines the panel that allows users to change the name of a Personanlizeable
 */
	public static final int NAME_CHANGE_PANEL = 2;

////////////////////////////////////////////////////////////////////////////////
/**
 * Creates a new Personalizer window with tabs for choosing a name,
 * a paint type, i.e. a color, a texture, a gradient, and for choosing shape
 * and size.
 * @param entity the personalizeable to modify.
 */
	public Personalizer(Personalizable entity) {
		//called to find 
		super( (Frame)(SwingUtilities.windowForComponent( ((JComponent)entity))) );
		this.entity = entity;
		getContentPane().setLayout(new BorderLayout());
		NameChooserPanel namePanel = new NameChooserPanel(entity);
		ShapeChooserPanel shapePanel = new ShapeChooserPanel(entity);
		PaintChooserPanel paintPanel = new PaintChooserPanel(entity);
		tabbedPane = new JTabbedPane();
		tabbedPane.addTab("Shape", shapePanel);
		tabbedPane.addTab("Image", paintPanel);
		tabbedPane.addTab("Name",  namePanel);	
		getContentPane().add(tabbedPane, BorderLayout.CENTER);
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Sets the selected pane at startup to whatever panel is at index.
 * @param int an index number.  Use one of the constants defined by this class.
 */
	public void setSelectedPane(int index) {
		tabbedPane.setSelectedIndex(index);
		}
	}