
package org.datamanager.userinterface.cerulean.model.data.storage;

import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.userinterface.cerulean.model.event.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;
import org.datamanager.userinterface.cerulean.model.data.storage.*;
import java.util.*;
import java.io.Serializable;

////////////////////////////////////////////////////////////////////////////////
/**
 * A collection of Clusters.  Similiar in function to a Vector.
 */

public class ClusterList implements Serializable {
	Vector clusters;
	private static final int DEFAULT_NUMBER_OF_CLUSTERS = 20;
////////////////////////////////////////////////////////////////////////////////
/**
 * Create a new cluster list with the default number of clusers.
 */
	public ClusterList() {
		clusters = new Vector(DEFAULT_NUMBER_OF_CLUSTERS);
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Create a new cluster list with the default number of clusers.
 */
	public ClusterList(int numberOfClusters) {
		clusters = new Vector(numberOfClusters);
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Adds the specified cluster to the list.
 * @param the cluster to add
 */
	public void addCluster(InterfaceCluster cluster) {
		clusters.add(cluster);
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Removes the specified cluster from the list.
 * @param the cluster to remove
 */
	public void removeCluster(InterfaceCluster cluster) {
		clusters.remove(cluster);
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Retrieves the cluster at the specified index.
 * @param index the index to insert the cluster at
 * @return the cluster at index
 */ 
	public InterfaceCluster elementAt(int index) {
		return (InterfaceCluster)clusters.elementAt(index);
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Inserts a cluster at the specified index.
 * @param cluster the cluster to add
 * @param index the index to insert the cluster at
 */
	public void insertElementAt(InterfaceCluster cluster, int index) {
		clusters.insertElementAt(cluster, index);
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Removes the cluster at the specified index and returns it.
 * @param index the index to remove the cluster at.
 * @return the cluster removed
 */
	public InterfaceCluster removeElementAt(int index) {
		InterfaceCluster cluster = elementAt(index);
		clusters.removeElementAt(index);
		return cluster;
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Returns true if the list contains the specified cluster.
 * @return true or false
 */
	public boolean contains(InterfaceCluster cluster) {
		return clusters.contains(cluster);
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * The number of clusters in the list.
 * @retun the number of clusters in the list
 */
	public int size() {
		return clusters.size();
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Converts the contents to a string representation
 * @return a string representation of the contents
 */
	public String toString() {
		return clusters.toString();
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Finds a cluster containing the specified InterfaceEntity
 * @return the InterfaceCluster that contains the specified entity.  This method
 *  may return null if no cluster is found.
 */
	public InterfaceCluster getClusterContaining(InterfaceEntity entity) {
		InterfaceCluster cluster = null;
		for (int i = 0; i <= this.size() - 1; i++) {
			if (this.elementAt(i).contains(entity)) {
				cluster = this.elementAt(i);
				break;
				}
			}
		return cluster; //may be null if not found!
		}
	}	
