package org.datamanager.userinterface.cerulean.model.data.transfer;
////////////////////////////////////////////////////////////////////////////////

import org.datamanager.userinterface.cerulean.view.component.*;
import org.datamanager.tools.Debug;
import java.awt.*;
import java.awt.event.*;
import java.awt.datatransfer.*;
import java.awt.dnd.*;
import javax.swing.*;
import java.awt.geom.*;
import java.io.*;

////////////////////////////////////////////////////////////////////////////////
/**
 * InterfaceEntityTransferable represents a class encompassing an 
 * InterfaceEntityComponent.  This class is used by the drag and drop
 * implementation.
 */
public class InterfaceEntityTransferable implements Transferable, Serializable {
	private String localFlavor;
	private InterfaceEntityComponent transferableEntity;
	private DataFlavor[] supportedFlavors;

////////////////////////////////////////////////////////////////////////////////
/**
 * Creates a new InterfaceEntityTransferable whose value is that of the
 * specified entity
 */
	public InterfaceEntityTransferable(InterfaceEntityComponent entity) {
		this.transferableEntity = entity;
		localFlavor = DataFlavor.javaJVMLocalObjectMimeType +
			"; class=org.datamanager.userinterface.cerulean." +
			"view.component.InterfaceEntityComponent";	
		
		try {	
			supportedFlavors = new DataFlavor[1];
			supportedFlavors[0] = new DataFlavor(localFlavor);
			//flavorArray[0] = new DataFlavor(localFlavor);
			}
		catch (ClassNotFoundException e) {
			Debug.assert("error in transferable");
			supportedFlavors = new DataFlavor[0];
			}
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Returns the object represented by this transferable.
 */
	public Object getTransferData(DataFlavor flavor)
		 throws UnsupportedFlavorException, IOException {
		if (flavor.isMimeTypeEqual(localFlavor)) {
			return transferableEntity;
			}
		else {
			Debug.assert("dataflavor is unsupported " + flavor);
			throw new UnsupportedFlavorException(flavor);
			}
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Returns a list of supported data flavors.
 */
	public DataFlavor[] getTransferDataFlavors() {
/*		DataFlavor[] flavorArray = new DataFlavor[1];
		try {	
			flavorArray[0] = new DataFlavor(localFlavor);
			}
		catch (ClassNotFoundException e) {
			flavorArray = new DataFlavor[0];
			}
*/
		return supportedFlavors;
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Returns whether or not a data flavor is supported.
 */
	public boolean isDataFlavorSupported(DataFlavor flavor) {
		if (flavor.isMimeTypeEqual(localFlavor)) {
			return true;
			}
		else {
			return false;
			}
		}
	}