package org.datamanager.userinterface.cerulean.model.event;

import org.datamanager.userinterface.cerulean.model.InterfaceCluster;
import java.util.EventObject;

////////////////////////////////////////////////////////////////////////////////
/**
 * The base class for all events sent out when a change to a cluster occurs.
 * This event encapsulates information about the event and the cluster that
 * fired the event.
 * A ClusterEvent is passed to every ClusterListener that registered with the
 * InterfaceClusterManager.
 *
 * @see ClusterListener
 * @see InterfaceClusterManager
 * @see InterfaceCluster
 *
 * @author Gordon Murphy
 */
public class ClusterEvent extends EventObject {
	protected InterfaceCluster cluster;

////////////////////////////////////////////////////////////////////////////////
/**
 * Creates a new cluster event object for the specified cluster.
 * @param source the object that caused the event to be fired.
 * @param cluster the cluster that fired the event.
 */
	public ClusterEvent(Object source, InterfaceCluster cluster) {
		super(source);
		setCluster(cluster);
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Sets the cluster this event was fired from.
 * @param cluster the cluster that fired the event.
 */
	protected void setCluster(InterfaceCluster cluster) {
		this.cluster = cluster;
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Retrieves the cluster that the event orinates from.
 * @return the cluster that fired the event.
 */
	public InterfaceCluster getCluster() {
		return cluster;
		}
	}