package org.datamanager.userinterface.cerulean.model.event;

import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.userinterface.cerulean.model.event.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import java.awt.geom.*;
/**
 * Manages the listener lists and the firing of events relating 
 * to InterfaceEntities.
 *
 * @see InterfaceEntity
 * 
 * @author Gordon Murphy, gpmurphy@indiana.edu
 * @author Bryan Dawson, bdawson@indiana.edu
 */
public class InterfaceEntityEventManager {
	private EventListenerList entityListenerList;

/**
 * Creates a new manager with an empty listener list.
 */
	public InterfaceEntityEventManager() {
		entityListenerList = new EventListenerList();
		}
/**
 * Register a class to listen for entity events.
 * @param listener the listener to add
 */
	public void addEntityListener(EntityListener listener) {
		entityListenerList.add(listener.getClass(), listener);
		}
/**
 * Unregister a class to listen for entity events.
 * @param listener the listener to remove
 */
	public void removeEntityListener(EntityListener listener) {
		entityListenerList.remove(listener.getClass(), listener);
		}
/**
 * Fire an event signalling that an entity was created.
 * @param source the originator of the event
 * @param entity the newly created entity
 */
	public void fireEntityCreated(Object source, InterfaceEntity entity) {
		Object[] listeners = entityListenerList.getListenerList();
		EntityEvent entityEvent = new EntityEvent(source, entity);
		for(int i = listeners.length - 2; i>=0; i-=2) {
			((EntityListener)listeners[i+1]).entityCreated(entityEvent);
			}
		}
/**
 * Fire an event signalling an entity has been selected.
 * @param source the originator of the event.
 * @param entity the selected entity.
 */
	public void fireEntitySelected(Object source, InterfaceEntity entity) {
		Object[] listeners = entityListenerList.getListenerList();
		EntityEvent entityEvent = new EntityEvent(source, entity);
		for(int i = listeners.length - 2; i>=0; i-=2) {
			((EntityListener)listeners[i+1]).entitySelected(entityEvent);
			}
		}
/**
 * Fire an event signalling an entity was unselected.
 * @param source the originator of the event
 * @param entity the unselected entity.
 */
	public void fireEntityUnselected(Object source, InterfaceEntity entity) {
		Object[] listeners = entityListenerList.getListenerList();
		EntityEvent entityEvent = new EntityEvent(source, entity);
		System.out.println("fired entity unselected in event man");
		for(int i = listeners.length - 2; i>=0; i-=2) {
			((EntityListener)listeners[i+1]).entityUnselected(entityEvent);
			}
		}
/**
 * Fire an event signalling an entity has been opened.
 * @param source the originator of the event
 * @param entity the opnened entity.
 */
	public void fireEntityOpened(Object source, InterfaceEntity entity) {
		Object[] listeners = entityListenerList.getListenerList();
		EntityEvent entityEvent = new EntityEvent(source, entity);
		for(int i = listeners.length - 2; i>=0; i-=2) {
			((EntityListener)listeners[i+1]).entityOpened(entityEvent);
			}
		}
/**
 * Fire an event signalling that entity has been attached.
 * @param source the originator of the event
 * @param baseEntity the entity to which another entity is being attached.
 * @param attachedEntity the entity that is being attached
 */
	public void fireEntityAttached(Object source, InterfaceEntity baseEntity, InterfaceEntity attachedEntity) {
		Object[] listeners = entityListenerList.getListenerList();
		EntityBoundEvent entityEvent = new EntityBoundEvent(source, baseEntity, attachedEntity);
		for(int i = listeners.length - 2; i>=0; i-=2) {
			((EntityListener)listeners[i+1]).entityAttached(entityEvent);
			}
		}
		/**
 * Fire an event signalling that entity has been detached.
 * @param source the originator of the event
 * @param baseEntity the entity fromwhich another entity is being detached.
 * @param detachedEntity the entity that is being detached
 */
	public void fireEntityDetached(Object source, InterfaceEntity baseEntity, InterfaceEntity detachedEntity) {
		Object[] listeners = entityListenerList.getListenerList();
		EntityBoundEvent entityEvent = new EntityBoundEvent(source, baseEntity, detachedEntity);
		for(int i = listeners.length - 2; i>=0; i-=2) {
			((EntityListener)listeners[i+1]).entityDetached(entityEvent);
			}
		}
/**
 * Fires an event signalling that an entity has been moved.
 * @param source the originator of the event
 * @param entity the entity that is being attached
 * @param x the x coordinate
 * @param y the y coordinate
 * @param z the z coordinate
 */
	public void fireEntityMoved(Object source, InterfaceEntity entity, int x, int y, int z) {
		Object[] listeners = entityListenerList.getListenerList();
		EntityMovedEvent entityEvent = new EntityMovedEvent(source, entity,x,y,z);
		for(int i = listeners.length - 2; i>=0; i-=2) {
			((EntityListener)listeners[i+1]).entityMoved(entityEvent);
			}
		}
/**
 * Fires an event signalling that an entity has been modified.
 * @param source the originator of the event.
 * @param entity the entity that was modified.
 */
	public void fireEntityModified(Object source, InterfaceEntity entity) {
		Object[] listeners = entityListenerList.getListenerList();
		EntityEvent entityEvent = new EntityEvent(source, entity);
		for(int i = listeners.length - 2; i>=0; i-=2) {
			((EntityListener)listeners[i+1]).entityModified(entityEvent);
			}
		}
	}