package org.datamanager.userinterface.cerulean.model.menu;

import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.view.component.*;
import org.datamanager.userinterface.cerulean.controller.action.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.userinterface.cerulean.model.menu.*;
import org.datamanager.userinterface.cerulean.model.event.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;
import org.datamanager.userinterface.cerulean.model.data.storage.*;
import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;

/**
 * A popup menu that entities display.
 * Currently, they display the following:<br>
 * <ul>
 * <li>Remove From Cluster</li>
 * <li>Remove From Knownspace</li>
 * <li>Duplicate Entity</li>
 * <li>Create New Cluster (creates a new cluster
 *     containing currently selected entities</li>
 * <li>Enhance Weight (does nothing)</li>
 * <li>Diminish Weight (does nothing)</li>
 * <li>Personalize</li>
 * <li>Show Name</li>
 * <li>View Attributes</li>
 * <li>Add to (produces a list of clusters to add the entity to.</li>
 */
 
public class InterfaceEntityPopupMenu extends InterfacePopupMenu implements ActionListener {
	private JMenuItem delete;
	private JMenuItem remove;
	private JMenuItem personalize;
	private JMenuItem enhance;
	private JMenuItem diminish;
	private JCheckBoxMenuItem showLabel;
	private JMenuItem removeLabel;
	private JMenuItem createNewCluster;
	private InterfaceClusterMenu clusterMenu;
	InterfaceEntityComponent entity;
	public InterfaceEntityPopupMenu(InterfaceEntityComponent entity) {
		super();
		this.entity = entity;

		remove = new JMenuItem("Remove From Cluster");
		RemoveEntityFromClusterAction removeEntityAction;
		removeEntityAction = new RemoveEntityFromClusterAction(entity.getInterfaceEntity());
		remove.addActionListener(removeEntityAction);
		add(remove);

		RemoveFromPoolAction deleteAction = new RemoveFromPoolAction(entity.getInterfaceEntity());
		delete = new JMenuItem("Remove From Knownspace");
		delete.addActionListener(deleteAction);
		add(delete);

		JMenuItem duplicate = new JMenuItem("Duplicate Entity");
		add(duplicate);

		CreateNewClusterAction newClusterAction = new CreateNewClusterAction();
		createNewCluster = new JMenuItem("Create new cluster");
		createNewCluster.addActionListener(newClusterAction);	
		add(createNewCluster);
		add(new JSeparator());

		enhance = new JMenuItem("Enhance Weight");
		enhance.addActionListener(this);
		add(enhance);

		diminish = new JMenuItem("Diminish Weight");
		add(diminish);

		add(new JSeparator());

		personalize = new JMenuItem("Personalize");
		personalize.addActionListener(new PersonalizeAction(entity));
		add(personalize);

		showLabel = new JCheckBoxMenuItem("Show name");
		showLabel.addActionListener(this);
		add(showLabel);
		
		JMenuItem viewAttributes = new JMenuItem("View Attributes");
		viewAttributes.addActionListener(new ViewAttributesAction(entity.getInterfaceEntity()));
		add(viewAttributes);

		add(new JSeparator());

		clusterMenu = new AddEntityToClusterMenu("Add to", entity.getInterfaceEntity());
		add(clusterMenu);
		}
	public void actionPerformed(ActionEvent e) {
		if (e.getSource() == delete) {
			System.out.println("deleting Entity from Knownspace");
			}
		else if (e.getSource() == enhance) {
			int x = entity.getLocation().x;
			int y = entity.getLocation().y;
			int z = entity.getWeight();
			entity.getInterfaceEntity().setMoved(entity,x,y,z+10);
			System.out.println("enhancing");
			}
		else if (e.getSource() == showLabel) {
			if (showLabel.getState())
				entity.showLabel();
			else entity.removeLabel();
			}
		else if (e.getSource() == removeLabel) {
			entity.removeLabel();
			}
		}
	}