package org.datamanager.userinterface.cerulean.model.personalize;

import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.tools.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.userinterface.cerulean.model.event.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;
import org.datamanager.userinterface.cerulean.model.data.storage.*;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import java.awt.geom.*;
import java.util.Vector;
import java.io.File;

/**
 * A panel that allows a shape and size to be chosen for a given personalizeable 
 * object.
 *
 * @see Personalizeable
 * @see Personalizer
 *
 * @author Gordon Murphy (gpmurphy@indiana.edu)
 * @author Bryan Dawson (bdawson@indiana.edu)
 */

public class ShapeChooserPanel extends JPanel implements ItemListener, ChangeListener {
	private JComboBox shapeList;
	private JSlider widthSlider;
	private JSlider heightSlider;
	private Personalizable entity;
	public ShapeChooserPanel(Personalizable entity) {
		super();
		this.entity = entity;
		Vector shapes = getShapes();
		shapeList = new JComboBox(shapes);
		shapeList.setEditable(false);
		shapeList.addItemListener(this);
		add(shapeList);

		widthSlider = new JSlider(0, 100, 50);
		widthSlider.addChangeListener(this);
		widthSlider.setValue(entity.getShape().getBounds().width);

		heightSlider = new JSlider(SwingConstants.VERTICAL, 0, 100, 50);
		heightSlider.addChangeListener(this);
		heightSlider.setValue(entity.getShape().getBounds().height);

		add(widthSlider);
		add(heightSlider);
		}
	public void itemStateChanged(ItemEvent e) {
		if (e.getSource() == shapeList) {
			if (e.getStateChange() == ItemEvent.SELECTED) {
				Shape shape = (Shape)shapeList.getSelectedItem();
				entity.setShape(shape);
				}
			}
		}
	public void stateChanged(ChangeEvent e) {
		if (e.getSource() == widthSlider) {
			double xWidth = (double)( widthSlider.getValue() );
			if (xWidth == 0) xWidth = 1d;
			double oldWidth = entity.getShape().getBounds().getWidth();
			if (oldWidth == 0) oldWidth = 1d;
			double xScale = xWidth / oldWidth;
			AffineTransform transform = AffineTransform.getScaleInstance(xScale, 1);
			Shape newShape = transform.createTransformedShape(entity.getShape());
			entity.setShape(newShape);
			}
		else if (e.getSource() == heightSlider) {
			double yHeight = (double)heightSlider.getValue();
			if (yHeight == 0) yHeight = 1d;
			double oldHeight = entity.getShape().getBounds().getHeight();
			if (oldHeight == 0) oldHeight = 1d;
			double yScale = yHeight / oldHeight;
			AffineTransform transform = AffineTransform.getScaleInstance(1, yScale);
			Shape newShape = transform.createTransformedShape(entity.getShape());
			entity.setShape(newShape);
			}
		}
	public Vector getShapes() {
		File file = new File("org" + File.separator +
				"datamanager" + File.separator +
				"userinterface" + File.separator + 
				"cerulean" + File.separator +
				"view" + File.separator + "shapes");
		Class shape = null;
		try {
			shape = Class.forName("java.awt.Shape");
			}
		catch (ClassNotFoundException e) {}
		Vector shapes = DynamicLoader.getFiles(file, shape);
		return shapes;
		}
	}