package org.datamanager.userinterface.cerulean.model.tree;

import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.JTree;

/**
 *This class inherites most of it's functionality from DefaultMutableTreeNode.
 *It's main function, however, is to serve as superclass of EntityNode and
 *ClusterNode.  It's one class that it does not inherite is abstract to allow
 *for polymorphism of that method.
 *
 *@author Bryan Dawson (bdawson@indiana.edu)
 *@author Gordon Murphy (gpmurphy@indiana.edu)
 *
 *@see ClickHandler
 */
//  Methods:
//  ~~~~~~~~
//  public abstract void display()
//          to be overriden by it's subclasses.  To be used in the
//          SelectionHandler to display the contents of the Entities.
//  public abstract void select();
//          to be overriden by it's subclasses.  To be used to set the 
//          selection of entities. 
//  public abstract void handlePopup(JTree, int,int)
//         To be overriden by subclasses.  This allows subclasses to be
//         able to display popup menus.
/////////////////////////////////////////////////////////////////////
public abstract class InterfaceNode extends DefaultMutableTreeNode
   {
   ///////////////////////////////////////////////////////////////
   /**
    * Does nothing. Is needed for there to be subclasses.
    */
   public InterfaceNode()
      { }
   ///////////////////////////////////////////////////////////////
   /**
    *Calls the superclass with the given parameter.
    *@param string Is passed to the superclass constructor.
    */
   public InterfaceNode(String string)
      { 
       super(string);
      }
   ////////////////////////////////////////////////////////
   /**
    *To be implemented by subclasses.To be used in the
    *SelectionHandler to display the contents of the Entities.
    */
   public abstract void display();
   ///////////////////////////////////////////////////////////////
   /**
    *To be implemented by subclasses.  Used to set the  selection of entities. 
    */
   public abstract void select();
   ///////////////////////////////////////////////////////////////
   /**
    *To be implemented by subclasses.  This allows subclasses to be able
    * to display popup menus.
    */
   public abstract void handlePopup(JTree tree, int x, int y);
   }
        
                


