package org.datamanager.userinterface.cerulean.model.undo;

import org.datamanager.userinterface.cerulean.view.undo.HistoryList;
import org.datamanager.userinterface.cerulean.model.undo.InterfaceUndoManager;
import org.datamanager.userinterface.cerulean.model.undo.InterfaceUndoEdit;
import org.datamanager.userinterface.cerulean.model.event.UndoDiedListener;
import javax.swing.event.UndoableEditListener;
import javax.swing.event.UndoableEditEvent;
import javax.swing.DefaultListModel;

/**
 *This class is responsible for keeping track of all of the InterfaceUndoEdit's
 *that occur in a session of Knownspace.  This class is relayed the
 *InterfaceUndoEdit's via UndoableEvent's.  It also knows when to remove an
 *edit for the model when it recieves UndoDiedEvent's.
 *
 *@author Bryan Dawson (bdawson@indiana.edu)
 *@author Gordon Murphy (gpmurphy@indiana.edu)
 * 
 *@see org.datamanager.userinterface.cerulean.view.undo.HistoryList
 *@see org.datamanager.userinterface.cerulean.model.undoInterfaceUndoMangager
 *@see org.datamanager.userinterface.cerulean.model.undo.InterfaceUndoEdit
 *@see UndoDiedListener
 *@see javax.swing.event.UndoableEditListener
 *@see javax.swing.event.UndoableEditEvent
 *@see javax.swing.DefaultListModel
 */
//  Mehtods(also see DefaultListModel):
//  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//  public HistoryListModel()
//          Add the various listeners.
//  public void undoableEditHappened(UndoableEditEvent)
//          Gets the edit from the event, and adds to the beginning of the list
//  public void undoEditDied(UndoDiedEvent)
//          Gets the edit from the event, and removes it from the list
/////////////////////////////////////////////////////////////////////

public class HistoryListModel extends DefaultListModel implements
                                    UndoableEditListener, UndoDiedListener
   {
   //the instance of InterfaceUndoManager
   private InterfaceUndoManager manager;

   ////////////////////////////////////////////////////////
   /**
    * Add the listeners.
    */
   public HistoryListModel()
     {
     manager = InterfaceUndoManager.getInstance();
     manager.addUndoableEditListener(this);
     manager.addUndoDiedListener(this);
     }

   ////////////////////////////////////////////////////////
   /**
    *From the UndoalbeEditListener interface, adds the edit
    * to the beginning of the list.
    */
   public void undoableEditHappened(UndoableEditEvent event)
      {
      InterfaceUndoEdit edit = (InterfaceUndoEdit)event.getEdit();
      this.insertElementAt(edit, 0);
      }

   ////////////////////////////////////////////////////////
   /**
    *From the UndoDiedListener interface, removes the edit
    * from the list.
   */
   public void undoEditDied(UndoableEditEvent event)
      {
      InterfaceUndoEdit edit = (InterfaceUndoEdit)event.getEdit();
      this.removeElement(edit);
      }

  }//end of class 

