package org.datamanager.userinterface.cerulean.model.undo;

import org.datamanager.userinterface.cerulean.model.undo.InterfaceUndoManager;
import javax.swing.undo.AbstractUndoableEdit;

/**
 *The superclass for all undo edits in the Cerulean interface.  Its main
 *feature is that it overrides the die() method so that when an Edit dies
 *it fires UndoDieEvent to InterfaceUndoManager's listeners.  All other
 *functionallity it gets from AbstractUndoableEdit
 *
 *@author Bryan Dawson (bdawson@indiana.edu)
 *@author Gordon Murphy (gpmurphy@indiana.edu)
 *
 *@see org.datamanager.userinterface.cerulean.model.undo.InterfaceUndoManager
 *@see javax.swing.undo.AbstractUndoableEdit
 */
//  Methods (also see AbstactUndoableEdit):
//  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//  public void die()
//  	fires a UndoDieEvent to listeners, and everything else that die() in
//  	AbstractUndoableEdit does.
////////////////////////////////////////////////////////////////////////

public abstract class InterfaceUndoEdit extends AbstractUndoableEdit
   {
   ////////////////////////////////////////////////////////
   /**
    * Do everything of the superclass and fire an event
    */
   public void die()
      {
      super.die();
      InterfaceUndoManager.getInstance().fireUndoDied(this);
      }	

   }//end of class      

