package org.datamanager.userinterface.cerulean.view.component;

import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.Shape;
import javax.swing.BorderFactory;
import javax.swing.JComponent;
import javax.swing.JLayeredPane;
import javax.swing.SwingUtilities;
import org.datamanager.userinterface.cerulean.controller.drop.StageDropListener;
import org.datamanager.userinterface.cerulean.controller.mouse.StageMouseListener;
import org.datamanager.userinterface.cerulean.controller.stage.StageComponentStageListener;
import org.datamanager.userinterface.cerulean.model.CircleManager;
import org.datamanager.userinterface.cerulean.model.InterfaceEntityManager;
import org.datamanager.userinterface.cerulean.model.Stage;
import org.datamanager.userinterface.cerulean.model.data.storage.ClusterList;
import org.datamanager.userinterface.cerulean.model.data.storage.InterfaceEntityList;
import org.datamanager.userinterface.cerulean.view.icon.StageIcon;
import org.datamanager.userinterface.cerulean.view.layout.StageLayout;
import java.util.Vector;

/**
 * 
 */
public class StageComponent extends Circle {
	private Stage stage;
	private InterfaceEntityManager entityManager;
	private ClusterList clusterList;
	private Rectangle selectionBox;
	private Rectangle lastSelectionBox;
	private boolean isDrawingSelectionBox;
/**
 * Create a new stage component that listens for StageEvents.  
 */
	public StageComponent() {
		super();
		setLayout(new StageLayout());
		setName("the Stage");
		setToolTipText(getName());
		CircleManager circleManager = CircleManager.getInstance();
		circleManager.setStage(this);
		setBorder(BorderFactory.createEmptyBorder(60, 60, 60, 60));
		circleIcon = new StageIcon(new Color(100, 100, 100));
		stage = new Stage();	
		clusterList = new ClusterList();
		StageMouseListener mouseListener = new StageMouseListener(this);
		addMouseListener(mouseListener);
		addMouseMotionListener(mouseListener);
		entityManager = InterfaceEntityManager.getInstance();
		StageDropListener listener = new StageDropListener(this);
		selectionBox = new Rectangle();
		lastSelectionBox = new Rectangle();
		isDrawingSelectionBox = false;
		stage.addStageListener(new StageComponentStageListener(this));
		}
	public void drawSelectionBox(Point origin, Point end) {
		setDrawingSelectionBoxEnabled(true);
		selectionBox = new Rectangle(origin);
		selectionBox.add(end);
		int x = (int)(lastSelectionBox.getWidth()) + end.x;
		int y = (int)lastSelectionBox.getHeight() + end.y;
		if (selectionBox.contains(x,y)) {
			System.out.println("bigger");
			repaint(selectionBox);
			}
		else {
			System.out.println("smaller");
			repaint(lastSelectionBox);
			}
		}
	public void setDrawingSelectionBoxEnabled(boolean isDrawing) {
		isDrawingSelectionBox = isDrawing;
		}
	public void paintComponent(Graphics g) {
		super.paintComponent(g);
		if (isDrawingSelectionBox) {
			Graphics2D g2 = (Graphics2D)g;
			g2.setPaint(Color.black);
			g2.draw(selectionBox);
			lastSelectionBox = selectionBox;
			}
		}
	public void groupEntitiesAt(Point origin, Point end) {
		Rectangle selectionBox = new Rectangle(origin);
		selectionBox.add(end);
		InterfaceEntityList selectedComponents = new InterfaceEntityList();
		Component[] components = getComponents();
		for (int i = 0; i <= components.length - 1; i++) {
			Rectangle componentBox = components[i].getBounds();
			if ( (componentBox.intersects(selectionBox))&&
				(components[i] instanceof InterfaceEntityComponent) ) {
				InterfaceEntityComponent component = (InterfaceEntityComponent)components[i];
				selectedComponents.addEntity(component.getInterfaceEntity());
				}
			}
		entityManager.setGroupedEntities(selectedComponents);
		}
	public void ungroupAllEntities() {
		entityManager.ungroupAllEntities();
		}
	public Shape getStageShape() {
		return circleIcon.getIconShape();
		}
	public Point convertPoint(Component source, int x, int y) {
		return SwingUtilities.convertPoint(this, x, y, source);
		}
	public Stage getStage() {
		return stage;
		}
	}