package org.datamanager.userinterface.cerulean.view.component;

import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.Paint;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.Shape;
import java.awt.geom.AffineTransform;
import javax.swing.AbstractButton;
import javax.swing.JCheckBox;
import javax.swing.JComponent;
import javax.swing.JToggleButton;
import org.datamanager.userinterface.cerulean.model.CircleManager;
import org.datamanager.userinterface.cerulean.view.icon.TabIcon;
import org.datamanager.userinterface.cerulean.view.icon.TabIconDisabled;
import org.datamanager.userinterface.cerulean.view.icon.TabIconEnabled;

/**
 * A Tab that appears on the outside of the stage.  Can be selected and
 * unselected.  
 */
public class Tab extends JCheckBox {
	private int currentHeight;
	private int currentWidth;
	private String tabLabel;
	private CircleManager circleManager;
	private TabIconEnabled tabIconEnabled;
	private TabIconDisabled tabIconDisabled;
/**
 * Create a new Tab with the specified name.
 * @param tabLabel the name of the tab
 */
	public Tab(String tabLabel) {
		this(tabLabel, Color.white);
		}
/**
 * Create a new Tab with the specified name and the specified color.
 * @param tabLabel the name of the tab.
 * @param paint the paint of the tab.
 */
	public Tab(String tabLabel, Paint paint) {
		super();
		tabIconEnabled =  new TabIconEnabled(tabLabel, paint);
		tabIconDisabled = new TabIconDisabled(tabLabel, paint);
		setPressedIcon(tabIconDisabled);
		setIcon(tabIconDisabled);
		setSelectedIcon(tabIconEnabled);
		setPressedIcon(tabIconDisabled);
		setDisabledIcon(tabIconDisabled);
		setDisabledSelectedIcon(tabIconDisabled);
		setOpaque(false);
		this.tabLabel = tabLabel;
		setToolTipText(tabLabel);
		//note: current build of swing will not change cursor back until user moves the mouse
		//still unfixed as of 10/26/99
		setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
		setSelected(false);
		setPreferredSize(new Dimension(60, 60));
		circleManager = CircleManager.getInstance();
		}
	private TabIcon[] getIcons() {
		return new TabIcon[] {tabIconEnabled};
		}
/**
 * Return the stage in the coordinates of the cluster.
 * @return the stage transformed to the coordinates of the tab.
 */
	public Shape getStage() {
		StageComponent tabParent = (StageComponent)circleManager.getStage();
		Shape stage = tabParent.getStageShape();
		Rectangle stageDimensions = stage.getBounds();

		//convert x,y coordinates of the stage to the x, y coordinates of the tab
		int stageXCoordinates = stageDimensions.x;
		int stageYCoordinates = stageDimensions.y;
		Point translatedCoordinates = tabParent.convertPoint(this, stageXCoordinates, stageYCoordinates);
		
		int xChange = translatedCoordinates.x - stageXCoordinates ;
		int yChange = translatedCoordinates.y - stageYCoordinates;
		
		AffineTransform transform = AffineTransform.getTranslateInstance(xChange, yChange);
		Shape transformedStage = transform.createTransformedShape(stage);
		return transformedStage;
		}
/**
 * Returns whether the point is contained by the tab.
 * @param x the x coordinate
 * @param y the y coordinate
 */
	public boolean contains(int x, int y) {
		Shape shape;
		if (isSelected())
			shape = tabIconEnabled.getIconShape();
		else 
			shape = tabIconDisabled.getIconShape();
 		return shape.contains(x, y);
		}

	}