package org.datamanager.userinterface.cerulean.view.icon;
import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.awt.geom.*;

public class CircleIcon implements CIcon {
	private int currentWidth, currentHeight;
	private Point pressedCoordinates;
	private String entityName;
	private Shape iconShape;
	private Paint currentPaint;
	private Rectangle iconDimensions;
	private int tabWidth;
	private int tabHeight;
	private CircleManager circleManager;
	private Insets iconInsets;
	public CircleIcon(Paint currentPaint) {
		setPaint(currentPaint);
		currentWidth = 240;
		currentHeight = 240;
		tabWidth = 30;
		tabHeight = 30;
		setIconDimensions(new Rectangle(tabWidth, tabHeight, currentWidth, currentHeight));
		circleManager = CircleManager.getInstance();
		setIconInsets(new Insets(0, 0, 0, 0));
		setNewIconShape(circleManager.getCurrentShape());
		}
	public void paintIcon(Component c, Graphics g, int x, int y) {
		Graphics2D g2 = (Graphics2D)g;
		JComponent jc = (JComponent)c;
		Dimension d = c.getPreferredSize();
		Insets insets = jc.getInsets();
		setIconInsets(insets);
		setIconDimensions(new Rectangle(tabWidth,tabHeight, d.width, d.height));
		updateIconShape(getIconShape());
		g2.setPaint(getPaint());
		g2.fill(getIconShape());
		}
	public void setIconInsets(Insets insets) {
		this.iconInsets = insets;
		}
	public Insets getIconInsets() {
		return iconInsets;
		}
	public void setPaint(Paint paint) {
		this.currentPaint = paint;
		}
	public Paint getPaint() {
		return currentPaint;
		}
	public int getIconWidth() {
		return getIconShape().getBounds().width;
		}
	public int getIconHeight() {
		return getIconShape().getBounds().height;
		}
	public void setIconDimensions(Rectangle iconDimensions) {
		this.iconDimensions = iconDimensions;
		}
	public Rectangle getIconDimensions() {
		return iconDimensions;
		}
	protected Shape getDefaultIconShape() {
		Rectangle dimensions = getIconDimensions();
		Ellipse2D.Double circle = new Ellipse2D.Double(30,
								30,
								dimensions.width - 60,
								dimensions.height - 60
								);
		return circle;
		}
	public void setIconShape(Shape iconShape) {
		this.iconShape = iconShape;
		}
	protected Shape getTransformedIconShape(Rectangle newBounds, Rectangle oldBounds, Shape iconShape) {
		Rectangle dimensions = newBounds;
		Rectangle oldSize = oldBounds;			
		Insets insets = getIconInsets();

		int xInsets = insets.left + insets.right;
		int yInsets = insets.bottom + insets.top;

		double deltaWidth = dimensions.getWidth() - oldSize.getWidth();
		double deltaHeight = dimensions.getHeight() - oldSize.getHeight();

		double xFactor = (dimensions.getWidth() - xInsets) / oldSize.getWidth();
		double yFactor = (dimensions.getHeight() - yInsets) / oldSize.getHeight();

		double x = iconShape.getBounds().getX();
		double y = iconShape.getBounds().getY();

		AffineTransform transform = AffineTransform.getScaleInstance(xFactor, yFactor);
		transform.translate((-oldSize.getX() + (xInsets/2))*xFactor,-(oldSize.getY()-(yInsets/2))*yFactor);
		//transform.translate((-x+(xInsets/2))*xFactor,-(y-(yInsets/2))*yFactor);
		//transform.translate(( -(x+xInsets) / 2)*xFactor,(-(y-yInsets)/2)*yFactor);
		Shape newIconShape =  transform.createTransformedShape(iconShape);
		return newIconShape;
		}
	public void setNewIconShape(Shape iconShape) {
		Rectangle dimensions = getIconDimensions();
		Rectangle oldSize = iconShape.getBounds();

		Shape newIconShape = getTransformedIconShape(dimensions, oldSize, iconShape);
		setIconShape(newIconShape);		
		}
	public Shape getIconShape() {
		return iconShape;
		}
	private void updateIconShape(Shape iconShape) {
		Rectangle dimensions = getIconDimensions();
		Rectangle oldSize = iconShape.getBounds();
		if (!dimensions.equals(oldSize)) {
			setNewIconShape(iconShape);
			}
		}
	}