package org.datamanager.userinterface.cerulean.view.icon;
import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.awt.geom.*;

public class ShapeIcon implements Icon {
	private int currentWidth, currentHeight;
	private Point pressedCoordinates;
	private String entityName;
	private Shape iconShape;
	private Paint currentPaint;
	private Rectangle stageDimensions;
	private int tabWidth;
	private int tabHeight;
	public ShapeIcon(Paint currentPaint) {
		setPaint(currentPaint);
		currentWidth = 240;
		currentHeight = 240;
		tabWidth = 30;
		tabHeight = 30;
		setStageDimensions(new Rectangle(tabWidth, tabHeight, currentWidth, currentHeight));
		setIconShape(getDefaultIconShape());
		}
	public void paintIcon(Component c, Graphics g, int x, int y) {
		Graphics2D g2 = (Graphics2D)g;
		JComponent jc = (JComponent)c;
		Dimension d = c.getPreferredSize();
		Insets insets = jc.getInsets();
		setStageDimensions(new Rectangle(tabWidth,tabHeight, d.width, d.height));
		//setIconShape(getDefaultIconShape());
		updateIconShape(getIconShape());
		g2.setPaint(getPaint());
		g2.fill(getIconShape());
		}
	public void setPaint(Paint newPaint) {
		currentPaint = newPaint;
		}
	public Paint getPaint() {
		return currentPaint;
		}
	public int getIconWidth() {
		return getIconShape().getBounds().width;
		}
	public int getIconHeight() {
		return getIconShape().getBounds().height;
		}
	public void setStageDimensions(Rectangle stageDimensions) {
		this.stageDimensions = stageDimensions;
		}
	public Rectangle getStageDimensions() {
		return stageDimensions;
		}
	protected Shape getDefaultIconShape() {
		Rectangle dimensions = getStageDimensions();
		Ellipse2D.Double circle = new Ellipse2D.Double(30,
								30,
								dimensions.width - 60,
								dimensions.height - 60
								);
		return circle;
		}
	public void setIconShape(Shape iconShape) {
		this.iconShape = iconShape;
		}
	public Shape getIconShape() {
		return iconShape;
		}
	protected void updateIconShape(Shape iconShape) {
		Rectangle dimensions = getStageDimensions();
		Rectangle oldSize = getIconShape().getBounds();
		if (!dimensions.equals(oldSize)) {
			double deltaWidth = dimensions.getWidth() - oldSize.getWidth();
			double deltaHeight = dimensions.getHeight() - oldSize.getHeight();
			double xFactor = (dimensions.getWidth() - 60) / oldSize.getWidth();
			double yFactor = (dimensions.getHeight() - 60 )/ oldSize.getHeight();
			AffineTransform transform = AffineTransform.getScaleInstance(xFactor, yFactor);
			transform.translate((-oldSize.getX()+30)*xFactor,-(oldSize.getY()-30)*yFactor);
			Shape newIconShape =  transform.createTransformedShape(iconShape);
			setIconShape(newIconShape);
			}
		}
	}