package org.datamanager.userinterface.cerulean.view.icon;
import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.view.paint.*;
import org.datamanager.userinterface.cerulean.view.component.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;

import java.awt.*;
import javax.swing.*;
import java.awt.geom.*;
/**
 * Class TabIcon represents the graphical view of a Cerulean Cluster Tab
 */
public class TabIcon implements Icon {

	protected int currentHeight;
	protected int currentWidth;
	protected String tabLabel;
	private Component currentComponent;
	private Rectangle currentComponentBounds;
	private Shape iconShape;
	private Paint tabColor;
	public TabIcon(String label) {
		currentHeight = 60;
		currentWidth = 60;
		setIconShape(getDefaultIconShape());
		tabLabel = label;
		tabColor = Color.white;
		}
	public TabIcon(String label, Paint color) {
		this(label);
		tabColor = color;
		}
	/**
	 * paints the graphical view of the button
       * @param c the component
	 */
	public void paintIcon(Component c, Graphics g, int x, int y) {
		Graphics2D g2 = (Graphics2D)g;
		paintShadow(c, g);
		g2.setPaint(tabColor);
		g2.fill(getIconShape());
		}
	public void paintBorder(Component c, Graphics g) {
		Graphics2D g2 = (Graphics2D)g;
		g2.setColor(c.getForeground());
		g2.draw(getIconShape());
		}
	public void paintShadow(Component c, Graphics g) {
		Graphics2D g2 = (Graphics2D)g;
		Paint paint = new RoundGradientPaint(currentWidth / 2, currentHeight / 2, new Color(64, 64, 64, 255), new Point2D.Double(0, currentWidth), new Color(192, 192, 192, 0));
		g2.setPaint(paint);
		Shape iconShape = getIconShape();
		AffineTransform transform = new AffineTransform();
		transform.setToTranslation(currentWidth/2, currentHeight/2);
		transform.scale(1.06, 1.06);
		transform.translate(-(currentWidth/2), -(currentHeight/2));
		g2.fill(transform.createTransformedShape(iconShape));
		}
	public void paintTabLabel(Component c, Graphics g) {
		Graphics2D g2 = (Graphics2D)g;
		Tab tab = (Tab)c;
		int panelHeight = tab.getParent().getHeight();
		int panelWidth = tab.getParent().getWidth();
		Point location = tab.getLocation();
		int width = (location.x - (panelWidth / 2));
		int height = (location.y - (panelHeight / 2));
		double rotationAngle = Math.atan((double)height/width) + (Math.PI/2);
		System.out.println(Math.toDegrees(rotationAngle));
		AffineTransform defaultTransform = g2.getTransform();
		if (rotationAngle > 180 && rotationAngle < 360) {
			rotationAngle = -rotationAngle;
			}
		AffineTransform transform = AffineTransform.getRotateInstance(rotationAngle, getIconWidth()/2, getIconHeight()/2);
		g2.setTransform(transform);
		g2.drawString(tabLabel, 0, getIconHeight()/2);
		g2.setTransform(defaultTransform);
		}
	protected Shape getDefaultIconShape() {
		Ellipse2D.Double circle = new Ellipse2D.Double(0,0, currentWidth, currentHeight);
		return circle;
		}
	public Shape getIconShape() {
		return iconShape;
		}
	protected void setIconShape(Shape iconShape) {
		this.iconShape = iconShape;
		}
	private void setIconWidth(int width) {
		currentWidth = width;
		}
	private void setIconHeight(int height) {
		currentHeight = height;
		}
	public int getIconWidth() {
		return currentWidth;
		}
	public int getIconHeight() {
		return currentHeight;
		}
	}