package org.datamanager.userinterface.cerulean.view.layout;
import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;
/**
 * @version 1.20 7 Oct 1998
 * @author Cay Horstmann
 */

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.util.*;

public class CircleLayout implements LayoutManager, LayoutManager2
{
   private int minWidth = 0;
   private int minHeight = 0;
   private int preferredWidth = 0, preferredHeight = 0;
   private boolean sizesSet = false;
   private int maxComponentWidth = 0;
   private int maxComponentHeight = 0;
   private Vector components, constraints;
   public CircleLayout() 
	   {
		components = new Vector();
		constraints = new Vector();
	   }
   public void addLayoutComponent(String name, Component comp)
   {}

   public void removeLayoutComponent(Component comp)
   {}

   public void setSizes(Container parent)
   {  if (sizesSet) return;
      int n = parent.getComponentCount();

      preferredWidth = 0;
      preferredHeight = 0;
      minWidth = 0;
      minHeight = 0;
      maxComponentWidth = 0;
      maxComponentHeight = 0;

      for (int i = 0; i < n; i++)
      {  Component c = parent.getComponent(i);
         if (c.isVisible()) {
         Dimension d = c.getPreferredSize();
         maxComponentWidth = Math.max(maxComponentWidth,
            d.width);
         maxComponentHeight = Math.max(maxComponentWidth,
            d.height);
         preferredHeight += d.height;
         }
      }
      preferredHeight += maxComponentHeight;
      preferredWidth = 2 * maxComponentWidth;
      minHeight = preferredHeight;
      minWidth = preferredWidth;
      sizesSet = true;
   }

   public Dimension preferredLayoutSize(Container parent)
   {  Dimension dim = new Dimension(0, 0);
      setSizes(parent);
      Insets insets = parent.getInsets();
      dim.width = preferredWidth + insets.left
         + insets.right;
      dim.height = preferredHeight + insets.top
         + insets.bottom;
      return dim;
   }

   public Dimension minimumLayoutSize(Container parent)
   {  Dimension dim = new Dimension(0, 0);
      setSizes(parent);
      Insets insets = parent.getInsets();
      dim.width = minWidth + insets.left + insets.right;
      dim.height = minHeight + insets.top + insets.bottom;
      return dim;
   }

   public void layoutContainer(Container parent)
   {  Insets insets = parent.getInsets();
      int containerWidth = parent.getSize().width
         - insets.left - insets.right;
      int containerHeight = parent.getSize().height
         - insets.top - insets.bottom;
      int xradius = (containerWidth - maxComponentWidth)
         / 2;
      int yradius = (containerHeight - maxComponentHeight)
         / 2;

      setSizes(parent);
      int xcenter = insets.left + containerWidth / 2;
      int ycenter = insets.top + containerHeight / 2;

      int n = components.size();
	  //System.out.println(nn);
      for (int i = 0; i < n; i++)
      {  Component c = (Component)components.elementAt(i);
		 Integer constraint = (Integer)constraints.elementAt(i);
		 double angle = (double)constraint.intValue();
		 //convert the angle to radians
		 angle = -1 * angle * (Math.PI / 180);
		 //System.out.println(angle);
         if (c.isVisible())
         {  Dimension d = c.getPreferredSize();
            //double angle = 2 * Math.PI * i / n;
            int x = xcenter
               + (int)(Math.cos(angle) * xradius);
            int y = ycenter
               + (int)(Math.sin(angle) * yradius);

            c.setBounds(x - d.width / 2, y - d.width / 2,
               d.width, d.height);
         }
      }

   }
   public void addLayoutComponent(Component comp, Object constraint)
	{
	   // System.out.println("" + comp);
		components.addElement(comp);
		constraints.addElement(constraint);		
	}
   public float getLayoutAlignmentX(Container target) 
	{
	   return (float).5;
	}
   public float getLayoutAlignmentY(Container target)
	{
		return (float).5;
	}
   public void invalidateLayout(Container target) 
	{
	}          
   public Dimension maximumLayoutSize(Container target) 
	{
	   return new Dimension(maxComponentWidth, maxComponentHeight);
	}
   
}

