package org.datamanager.userinterface.cerulean.view.sidepanel;

import javax.swing.border.EmptyBorder;
import javax.swing.JSplitPane;
import org.datamanager.userinterface.cerulean.view.undo.HistoryPane;
import org.datamanager.userinterface.cerulean.view.tree.EntityTreePane;
import org.datamanager.userinterface.cerulean.controller.sidepanel.SidePanelResizer;

/**
 *This class is meant to display the EntityTreePane, and HistoryPane of the
 * Cerulean User Interface.  It relies on the HistoryPane
 *class to determine the location of the divider inbetween the panes.  
 *Other than that it gets the majority of its functionality form its 
 *superclass JSplitPane.
 *
 *@author Bryan Dawson (<a href=mailto:bdawson@indiana.edu>bdawson@indiana.edu</a>)
 *@author Gordon Murphy (<a href=mailto:bdawson@indiana.edu>bdawson@indiana.edu</a>)
 *
 *@see HistoryPane
 *@see EntityTreePane
 *@see JSplitPane
 *@see SidePanelResizer
 */
// methods(also see JSplitPane):
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// public SidePanel()
//     	Creates the various panes needs that and sets the intial location of 
//     	the divider to the percentage defined by the HistoryPane constant
//     	PERCENTAGE_OF_SPLITPANE
//////////////////////////////////////////////////////////////////////  	

public class SidePanel extends JSplitPane
   {
   // The 2 components
   private HistoryPane history;
   private EntityTreePane treePane;
   
   ////////////////////////////////////////////////////////////
   /**
    * Setup the components and add them in.
    */
   public SidePanel()
      {
      super(JSplitPane.VERTICAL_SPLIT);
      
      //Set it up so that we use our own controls for expandsion
      setOneTouchExpandable(false);
      setDividerSize(0);
      
      //create the two panes, and set them up in the SidePanel
      history = new HistoryPane(this);
      treePane = new EntityTreePane();
      setTopComponent(treePane);
      setBottomComponent(history);
      
      //setup the intial location of the divider.
      setDividerLocation(HistoryPane.PERCENTAGE_OF_SPLITPANE);
      
      //setup the look of the pane      
      setBorder(new EmptyBorder(getInsets()));
      setOpaque(false);
      
      addComponentListener( new SidePanelResizer(history,this));	
      }

  }//end of class      
      
      
   
