package org.datamanager.userinterface.cerulean.view.undo;

import org.datamanager.userinterface.cerulean.model.undo.InterfaceUndoEdit;
import javax.swing.ListCellRenderer;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.ImageIcon;
import java.awt.Component;
import java.awt.Color;

/**
 *This class is meant to renderer the InterfaceUndoEdit's for the HistoryList.
 *Therefore, it goes on the assumtion that the object passed to it will be of
 *type InterfaceUndoEdit (so that it can determine what type of icon to set).
 *This class gets most of it's functionallity from JLabel.
 *
 *@author Bryan Dawson <a href=mailto:bdawson@indiana.edu>bdawson@indiana.edu</a>
 *@author Gordon Murphy <a href=mailto:gpmurphy@indiana.edu>gpmurphy@indiana.edu</a>
 *
 *@see InterfaceUndoEdit
 *@see ListCellRenderer
 *@see JLabel
 *@see Component
 */

// Methods:
// ~~~~~~~~
// public CListCellRenderer()
//         Create a renderer.
// public Component getListCellRendererComponent(JList, Object,int, boolean,
//                                              boolean)
//         Creates the component to be displayed in the list.  The component
//         is transparent, except when selected.  It sets the images based on
//         whether or not the CeruleanUndoEdit is undoable or not.
/////////////////////////////////////////////////////////////////////


public class InterfaceListCellRenderer extends JLabel implements
                                                       ListCellRenderer
   {
   //The images to be placed on the left of text
   private ImageIcon undoIcon;                
   private ImageIcon redoIcon;               

   ////////////////////////////////////////////////////////
   /**
    * Create the renderer, and create the icons.
    */
   public InterfaceListCellRenderer()
      {
      undoIcon = new ImageIcon("org/datamanager/userinterface"+
                       "/cerulean/view/undo/images/historyarrowactive.gif");
      redoIcon = new ImageIcon("org/datamanager/userinterface"+
                       "/cerulean/view/undo/images/historyarrowinactive.gif");

      setOpaque(false);
      setBackground(new Color(206,206,255));
      setForeground(Color.black);
      }

   ////////////////////////////////////////////////////////
   /**
    *Creates the component to be displayed by the list.  Which
    *  Icon it displays depends on the state of the CeruleanUndoEdit,
    *  whether is undoable or not.
    */
   public Component getListCellRendererComponent(JList list, Object value,
                int index, boolean isSelected, boolean cellHasFocus)
      {
      setText(value.toString()+"  ");

      //Going on the assumtion that this renderer will only be used to
      //display InterfaceUndoEdit's 
      InterfaceUndoEdit edit = (InterfaceUndoEdit)value;
      if(edit.canUndo())
         setIcon(undoIcon);
      else
         setIcon(redoIcon);

      //determine if we are to be transparent or not (ie selected).
      if(isSelected)
         setOpaque(true);
      else
         setOpaque(false);     
         
      return this;
      }

   }//end of class
